@@ -61,9 +61,9 @@ class QonsoExtractorSFR(QonsoExtractor):
             self.authentication = 'Done'
             self.manager.get(request)
       
-   def CheckForErrors(self, datas):
+   def CheckForErrors(self, html):
       r = re.compile('<p class="error">\s*<span>(.+?)<.*?</p>', re.DOTALL)
-      res = r.search(datas)
+      res = r.search(html)
       
       if res:
          DebugLog("Erreur trouvée : "+str(res.groups()) )
@@ -78,17 +78,16 @@ class QonsoExtractorSFR(QonsoExtractor):
       return False
 
    # Extraction des données, dépend de chaque opérateur
-   def DoExtractDatas(self, datas):
+   def DoExtractDatas(self, html):
       DebugLog("QonsoExtractorSFR::DoExtractDatas")
 
-      if self.CheckForErrors(datas):
+      if self.CheckForErrors(html):
          return
-      
       # Voix
-      DebugLog("\n_______________________________________________\nVoix\n")
-      DebugLog("-----------------------------------------------\n")
-      r = re.compile('vous reste %s de communication .* votre [Ff]orfait (.+?)\s*<b>%s' % (self.hmReS, self.hmReS), re.DOTALL)
-      res = r.search(datas)
+      DebugLog("\n_____________________________________\nVoix\n")
+      DebugLog("-------------------------------------\n")
+      r = re.compile('vous reste %s (?:de communication)?.* votre [Ff](?:orfait|ormule) (.+?)\s*<b>%s' % (self.hmReS, self.hmReS), re.DOTALL)
+      res = r.search(html)
       if res:
          self.model.SetConsoVoixMax( res.group(3) )
          self.model.SetConsoVoix( res.group(1), invert=True )
@@ -98,7 +97,7 @@ class QonsoExtractorSFR(QonsoExtractor):
          DebugLog("forfait2 = "+res.group(2))
       else:
          r = re.compile('votre [Ff]orfait.*?"(.*?)".*?[Vv]ous avez un [Ff]orfait .+?%s et vous avez consomm.*?%s de communication'%(self.hmReS,self.hmReS), re.DOTALL)
-         res = r.search(datas)
+         res = r.search(html)
          if res:
             self.model.SetForfait( res.group(1) )
             self.model.SetConsoVoixMax( res.group(2) )
@@ -108,23 +107,32 @@ class QonsoExtractorSFR(QonsoExtractor):
             DebugLog("voixMax1 = "+res.group(3))
 
       # Voix Supp
-      DebugLog("\n_______________________________________________\nVoix Supp\n")
-      DebugLog("-----------------------------------------------\n")
-#      r = re.compile("vous reste %s de communication .* votre option (\d+).+?heures d'appels" % self.hmReS, re.DOTALL)
-      r = re.compile("vous reste <b>((?:\d{1,2}\s*[Hh])?\s*(?:\d{1,3}\s*(?:mi?n)?))</b> de communication dans le cadre de votre option (\d+\s?h)eures d'appels", re.DOTALL)
-      res = r.search(datas)
+      DebugLog("\n____________________________________\nVoix Supp\n")
+      DebugLog("-------------------------------------\n")
+      r = re.compile("vous reste <b>((?:\d{1,2}\s*[Hh])?\s*(?:\d{1,3}\s*(?:mi?n)?))</b> de communication dans le cadre de votre option (\d+\s*h)eures", re.DOTALL)
+      res = r.search(html)
       if res:
          voixSuppMax = res.group(2)
          DebugLog("voixSupp = "+res.group(1))
          DebugLog("voixSuppMax = "+voixSuppMax)
          self.model.SetConsoVoixSuppMax( voixSuppMax+"00" )
          self.model.SetConsoVoixSupp( res.group(1), invert=True )
+      else:
+         r = re.compile("vous reste <b>((?:\d{1,2}\s*[Hh])?\s*(?:\d{1,3}\s*(?:mi?n)?))</b>\s+sur les\s+<b>((?:\d{1,2}\s*[Hh])?\s*(?:\d{1,3}\s*(?:mi?n)?))</b>.+?offertes", re.DOTALL)
+         res = r.search(html)
+         if res:
+            voixSuppMax = res.group(2)
+            DebugLog("voixSupp = "+res.group(1))
+            DebugLog("voixSuppMax = "+voixSuppMax)
+            self.model.SetConsoVoixSuppMax( voixSuppMax+"00" )
+            self.model.SetConsoVoixSupp( res.group(1), invert=True )
+      
             
       # Date de dernière communication
-      DebugLog("\n_______________________________________________\nDerniere communication\n")
-      DebugLog("-----------------------------------------------\n")
-      r = re.compile("prise\sen\scompte.*Le\s+(\d{1,2}.*?\d{2,4}).*?(\d{1,2}).*?(\d{1,2})\s*minutes", re.DOTALL)
-      res = r.search(datas)
+      DebugLog("\n_____________________________________\nDerniere communication\n")
+      DebugLog("-------------------------------------\n")
+      r = re.compile("prise\s*en\s*compte.*?Le\s+(\d{1,2}.*?\d{2,4}).*?(\d{1,2}).*?(\d{1,2})\s*minutes", re.DOTALL)
+      res = r.search(html)
       if res:
          DebugLog(res.groups())
          date = res.group(1)
@@ -133,33 +141,33 @@ class QonsoExtractorSFR(QonsoExtractor):
          DebugLog("last="+self.model.lastTime)
          
       # Date de prochaine facture
-      DebugLog("\n_______________________________________________\nProchaine facture\n")
-      DebugLog("-----------------------------------------------\n")
-      res = re.search("avant le.+?(\d{1,2}\s*.+?\d{2,4})", datas)
+      DebugLog("\n____________________________________\nProchaine facture\n")
+      DebugLog("------------------------------------\n")
+      res = re.search("avant le.+?(\d{1,2}\s*.+?\d{2,4})", html)
       if res:
          self.model.facture = "Prochaine facture : "+res.group(1)
-         self.model.facture = self.model.facture.replace("\n", " ")
+         self.model.facture = self.model.facture.replace("\n", " ").replace("\r", "")
          DebugLog("facture="+self.model.facture)
          
       # Report des minutes
-      DebugLog("\n_______________________________________________\nReport des minutes\n")
-      DebugLog("-----------------------------------------------\n")
+      DebugLog("\n_____________________________________\nReport des minutes\n")
+      DebugLog("-------------------------------------\n")
       r = re.compile("Report Forfait %s de communication"%self.hmReS, re.DOTALL)
-      res = r.search(datas)
+      res = r.search(html)
       if res:
          DebugLog("report = "+res.group(1))
          self.model.SetReport( res.group(1) )
 
       # Hors forfait
-      DebugLog("\n_______________________________________________\nHors forfait\n")
-      DebugLog("-----------------------------------------------\n")
+      DebugLog("\n_____________________________________\nHors forfait\n")
+      DebugLog("-------------------------------------\n")
       r = re.compile("hors forfait.*?(\d+[.,]?\d*)\s.\sTTC", re.DOTALL)
-      res = r.search(datas)
+      res = r.search(html)
       if res:
          self.model.SetConsoHorsForfait( res.group(1) )
          DebugLog("hforfait = "+res.group(1))
 
       # SMS
-      DebugLog("\n_______________________________________________\nSMS\n")
-      DebugLog("-----------------------------------------------\n")
+      DebugLog("\n_____________________________________\nSMS\n")
+      DebugLog("-------------------------------------\n")
       self.model.sms = "0"
