@@ -7,7 +7,7 @@ from PyQt4 import QtGui
 
 app = QtGui.QApplication(sys.argv)
 
-consoWin = QonsoView()
+consoWin = QonsoView(sys.argv)
 consoWin.show()
 
 sys.exit(app.exec_())
